# Make sure ccache is found
export PATH=/usr/local/opt/ccache/libexec:$PATH

cd ./plugins/obs-browser
git checkout origin/osx
cd -

mkdir build
cd build
cmake -DENABLE_SPARKLE_UPDATER=ON \
-DCMAKE_OSX_DEPLOYMENT_TARGET=10.10 \
-DDepsPath=/tmp/obsdeps \
-DVLCPath=$PWD/../../vlc-master \
-DBUILD_BROWSER=ON \
-DCEF_ROOT_DIR=$PWD/../../cef_binary_${CEF_BUILD_VERSION}_macosx64 ..